/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 *  USBSink - aboutdialog.cc
 *
 *  Copyright (C) 2006-2007 Marko Anastasov
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "common/nmv-log-stream-utils.h"
#include "aboutdialog.h"
#include "globalstrings.h"
#include "iconloader.h"

#include <config.h>

#include <list>

#include <glib/gi18n.h>

#include <gtkmm/aboutdialog.h>

namespace USBSink
{

namespace UI
{

using std::list;

std::auto_ptr<Gtk::AboutDialog>
AboutDialog::create(Gtk::Window& parent)
{
  LOG_FUNCTION_SCOPE_NORMAL_DD;

  std::auto_ptr<Gtk::AboutDialog> dialog;
  dialog.reset(new Gtk::AboutDialog());

  dialog->set_name(PACKAGE_NAME);
  dialog->set_version(PACKAGE_VERSION);
  dialog->set_comments(
    _("GNOME program for automatic file synchronization with removable drives"));
  
  list<Glib::ustring> authors;
  authors.push_back("Marko Anastasov <marko@marko.anastasov.name>");
  dialog->set_authors(authors);

  dialog->set_website("http://usbsink.sourceforge.net");
  dialog->set_website_label("Project Website");

  Glib::ustring license =
    "This program is free software; you can redistribute it and/or modify\n"
    "it under the terms of the GNU General Public License as published by\n"
    "the Free Software Foundation; either version 2 of the License, or\n"
    "(at your option) any later version.\n\n"
    
    "This program is distributed in the hope that it will be useful,\n"
    "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
    "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
    "GNU General Public License for more details.\n\n"
    
    "You should have received a copy of the GNU General Public License\n"
    "along with this program; if not, write to the \n"
    "Free Software Foundation, Inc., 59 Temple Place, Suite 330, \n"
    "Boston, MA  02111-1307  USA\n";
  dialog->set_license(license);

  // Translators: change this to your name, or separate multiple names with \n
  Glib::ustring translation_credits = _("translator-credits");
  dialog->set_translator_credits(translation_credits);

  try
  {
    Glib::RefPtr<Gdk::Pixbuf> icon =
      IconLoader::load_program_icon(ICON_SIZE_LARGE);

    dialog->set_logo(icon);
  }
  catch (const IconLoadingException& ex)
  {
    LOG_EXCEPTION_DD(ex.what());
  }

  dialog->set_transient_for(parent);

  dialog->signal_response().connect(
    sigc::hide(sigc::mem_fun(*dialog, &Gtk::Widget::hide)));

  return dialog;
}

} // namespace UI

} // namespace USBSink
