/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 *  USBSink - edittaskdialog.cc
 *
 *  Copyright (C) 2006 Marko Anastasov
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "blackfilelist.h"
#include "edittaskdialog.h"
#include "filelistloader.h"
#include "filelist.h"
#include "task.h"
#include "taskmanager.h"
#include "whitefilelist.h"

#include <list>
#include <string>
#include <vector>

#include <libgnomevfsmm/uri.h>

using std::list;
using std::vector;

using namespace USBSink::TaskHandling;

namespace USBSink
{

namespace UI
{

typedef Gtk::TreeModel::Children tree_children;
typedef std::list< Glib::RefPtr<Gnome::Vfs::Uri> > uri_list;

EditTaskDialog::EditTaskDialog(Gtk::Window& parent,
                               const USBSink::TaskHandling::SharedTask& task)
  :
  NewTaskDialog(parent),
  task_(task)
{
  // set up widgets

  // task name
  entry_task_name_->set_text(task_->get_name());
  entry_task_name_->set_sensitive(false);

  // target drive
  if (task->get_drive().get() != 0)
  {
    tree_children children = treemodel_drives_->children();
    tree_children::iterator it(children.begin());
    tree_children::iterator end(children.end());
    
    for ( ; it != end; ++it)
    {
      std::string item_udi((*it)[columns_removables_.col_udi]);

      if (item_udi == task_->get_drive_udi())
      {
	combobox_target_drive_->set_active(*it);
	break;
      }
    }
  }
  combobox_target_drive_->set_sensitive(false);

  // data flow
  combobox_data_flow_->set_active(static_cast<int>(task_->get_data_flow()));
  combobox_data_flow_->set_sensitive(false);

  // file list type
  const Glib::ustring file_list_type_string =
    task_->get_file_list()->get_type_string();

  if (file_list_type_string ==
      USBSink::TaskHandling::black_file_list_type_string)
  {
    combobox_file_list_type_->set_active(0);
  }
  else if (file_list_type_string ==
           USBSink::TaskHandling::white_file_list_type_string)
  {
    combobox_file_list_type_->set_active(1);
  }
  else
  {
    g_warning("Unknown type of list %s", file_list_type_string.c_str());
    combobox_file_list_type_->set_active(0);
  }

  // file list content
  textview_buffer_->set_text(
    task_->get_file_list()->get_text_string_for_display());

  // when to start
  combobox_start_->set_active(
    static_cast<int>(task_->get_start_time_option()));
  combobox_start_->set_sensitive(false);

  // timeout
  spinbutton_timeout_->set_value(
    static_cast<double>(task_->get_timeout() / ms_in_min));

  // source files
  uri_list src_files = task_->get_source_files();
  uri_list::iterator it(src_files.begin());
  uri_list::iterator end(src_files.end());

  for ( ; it != end; ++it)
  {
    add_uri_to_treeview(*it);
  }

  // target directory
  entry_target_dir_->set_text(task_->get_target_dir());
}

EditTaskDialog::~EditTaskDialog()
{
}

void
EditTaskDialog::on_response(int response_id)
{
  using namespace USBSink::TaskHandling;

  if (response_id == Gtk::RESPONSE_OK)
  {
    Manager* manager = Manager::instance();
    manager->remove_task(task_->get_id());

    NewTaskDialog::register_task();
  }
  else
  {
    dialog_->hide();
  }
}

void
EditTaskDialog::on_file_list_editor_clicked()
{
  // don't check for duplicate task name
  // emit with an empty string, meaning don't create a new list at startup
  signal_file_list_editor_request.emit(Glib::ustring());
}

} // namespace UI

} // namespace USBSink
