/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 *  USBSink - fileentry.cc
 *
 *  Copyright (C) 2007 Marko Anastasov
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "fileentry.h"

namespace USBSink
{

namespace TaskHandling
{

FileEntry::FileEntry(const Glib::RefPtr<Gnome::Vfs::Uri>& uri,
                     Inclusion type)
  :
  uri_(uri),
  inclusion_(type),
  is_dir_(Glib::file_test(uri_->get_path(), Glib::FILE_TEST_IS_DIR)),
  initially_checked_(true)
{
}

bool
FileEntry::is_dirty() const
{
  if ((status_ == FILE_STATUS_CREATED) || (status_ == FILE_STATUS_CHANGED))
    return true;

  return false;
}

void
FileEntry::reset_status()
{
  status_ = FILE_STATUS_NO_CHANGE;
}

bool
FileEntry::initial_check()
{
  bool res = initially_checked_;
  initially_checked_ = false;

  return res;
}

} // namespace TaskHandling

} // namespace USBSink
