/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 *  USBSink - fileentry.h
 *
 *  Copyright (C) 2007 Marko Anastasov
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __FILE_ENTRY_H__
#define __FILE_ENTRY_H__

#include "enums.h"
#include "filewatcher.h"

#include <list>
#include <tr1/memory>

#include <libgnomevfsmm/uri.h>

namespace USBSink
{

namespace TaskHandling
{

class FileEntry;
typedef std::tr1::shared_ptr<FileEntry> SharedFileEntry;

typedef std::list<SharedFileEntry> entry_list;
typedef entry_list::iterator entry_list_iter;
typedef entry_list::const_iterator entry_list_const_iter;

typedef std::list< Glib::RefPtr<Gnome::Vfs::Uri> > uri_list;

/**
 * Used internally by Task.
 */
class FileEntry
{
 public:
 
  FileEntry(const Glib::RefPtr<Gnome::Vfs::Uri>& uri, Inclusion type);

  std::list<SharedFileEntry> uri_to_file_entry_list(const uri_list& uris);

  Glib::RefPtr<Gnome::Vfs::Uri> get_uri() const { return uri_; }
  std::string                   get_path() const { return uri_->get_path(); }
  bool                          is_dirty() const;
  Inclusion                     get_inclusion() const { return inclusion_; }
  bool                          is_dir() const { return is_dir_; }

  void reset_status();
  bool initial_check();

  void set_status(FileStatus new_status) { status_ = new_status; }

 private:

  Glib::RefPtr<Gnome::Vfs::Uri> uri_;
  FileStatus status_;
  Inclusion inclusion_;
  bool is_dir_;

  bool initially_checked_;
};

struct file_entry_compare
  : public std::binary_function<SharedFileEntry, SharedFileEntry, bool>
{
  bool operator()(const SharedFileEntry& lhs,
                  const SharedFileEntry& rhs) const
  {
    return (lhs->get_uri()->get_path() < rhs->get_uri()->get_path());
  }
};

} // namespace TaskHandling

} // namespace USBSink

#endif // __FILE_ENTRY_H__
