/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 *  USBSink - filelistitem.h
 *
 *  Copyright (C) 2006 Marko Anastasov
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _TASK_FILE_LIST_ITEM_H_
#define _TASK_FILE_LIST_ITEM_H_

#include "taskitem.h"
#include "uncopyable.h"

#include <list>
#include <tr1/memory>
#include <vector>

#include <pcrecpp.h>

namespace USBSink
{

namespace TaskHandling
{

class FileListItem;

typedef std::tr1::shared_ptr<FileListItem> SharedFileListItem;

/** A regular expression item in a file list associated with a Task.
 */
class FileListItem : public Item, private Uncopyable
{
 public:

  static SharedFileListItem create(const Glib::ustring& regexp);
  
  virtual Glib::ustring get_name() const;
  virtual Glib::ustring get_name_formatted() const;

  virtual std::vector<Glib::ustring> get_text_for_display() const;

  virtual void set_name(const Glib::ustring& new_name);

  virtual bool match(const Glib::ustring&) const;

//  virtual std::list<Glib::ustring> match (
//    const std::list<Glib::ustring>& input_list) const;

 protected:

  FileListItem(const Glib::ustring& regexp);

 private:

  Glib::ustring value_;
  pcrecpp::RE   regexp_;
};

/* Implementation of FileListItem's inline functions. */

/** @return the value of regular expression that represents this item. */
inline Glib::ustring
FileListItem::get_name() const
{
  return value_;
}

/** @return the value of regular expression that represents this item. */
inline Glib::ustring
FileListItem::get_name_formatted() const
{
  return get_name();
}

/**
 * @return the value of regular expression that represents this item as
 * a (one-element) list. The point is to have one function overridden by
 * all implementors of Item which to return the object's text representation
 * which can be easily displayed on the screen.
 */
inline std::vector<Glib::ustring>
FileListItem::get_text_for_display() const
{
  std::vector<Glib::ustring> result(1);
  result.push_back(value_);

  return result;
}

/** @param new_name A new UTF-8 regular expression value for this item. */
inline void
FileListItem::set_name(const Glib::ustring& new_name)
{
  value_ = new_name;
}

} // namespace TaskHandling

} // namespace USBSink

#endif // _TASK_FILE_LIST_ITEM_H_
